/* Expected demand per customer for each price point */
data quant;
input case price expq;
cards;
1 2.00 3.0
2 2.25 2.7
3 2.50 2.1
4 2.75 2.0
;

proc optmodel;
/* The CASES set indexes the available price levels and related data  */
set CASES;

num expquan{CASES};
num pricept{CASES};

/* Hours, hourly customer rate, hourly wages */
num hours=6;
num hrcusts=30;
num hrwage=8;

/* Hourly production rates for proprietor (p) and staff (s) */
num p_rate=30;
num s_rate=20;

/* Read the prices and corresponding expected order quantities */
read data quant into CASES=[case] pricept=price expquan=expq; 

/* Set up the MILP optimization model */
var staff >=0 <=3 integer;
var setprice{CASES} binary;

/* Maximize profit */
max profit = sum{c in CASES}(setprice[c]*hours*hrcusts*expquan[c]*pricept[c]) 
             - (hours*hrwage*staff);

/* Meet expected hourly demand */
con hrdemand: sum{c in CASES} (setprice[c]*expquan[c]*hrcusts) <= p_rate + s_rate*staff;

/* Choose exactly one price */
con oneprice: sum{c in CASES} setprice[c] = 1;

/* Un-comment and use this command to fix a pricing decision */
/* Change the index of setprice as needed */
* fix setprice[1]=1;

/* Inspect the optimization model */
expand;

/* Invoke the MILP solver */
solve;

/* Output the optimal pricing and staffing decisions */
print pricept setprice staff;

quit;



